@@ -4,7 +4,7 @@ from cosapp_lab.script import cosapp_script, LOGO
 from cosapp_lab import __version__ as cosapp_lab_version
 from cosapp.core import __version__ as cosapp_version
 
-CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
+CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"], ignore_unknown_options=True)
 
 
 @click.group(
@@ -16,7 +16,6 @@ CONTEXT_SETTINGS = dict(help_option_names=["-h", "--help"])
 @click.pass_context
 def cosapp(ctx, version):
     """CosApp CLI tool."""
-    echo(LOGO)
     if version:
         echo(f"CosApp version {cosapp_version}")
         echo(f"CosApp Lab version {cosapp_lab_version}")
@@ -24,6 +23,7 @@ def cosapp(ctx, version):
         if ctx.invoked_subcommand is None:
             lab_app = cosapp_script["lab"]
             if lab_app is not None:
+                echo(LOGO)
                 lab_app()
             else:
                 echo(
@@ -51,7 +51,7 @@ def cosapp_module():
     "register", short_help="Register a CoSApp library as standalone module"
 )
 @click.argument("name")
-def cosapp_module_register(name):
+def cosapp_module_register(name: str):
     cosapp_script["cosapp_module_register"]([name])
 
 
@@ -68,11 +68,6 @@ def cosapp_module_register():
     cosapp_script["cosapp_module_list"]()
 
 
-@cosapp_module.command("update", short_help="Update all modules configuration")
-def cosapp_module_register():
-    cosapp_script["cosapp_module_update"]()
-
-
 @cosapp.command("load", short_help="Start a CosApp module in standalone mode")
 @click.argument("module", default=None, required=False)
 @click.option(
@@ -101,11 +96,21 @@ def cosapp_module_register():
     type=int,
     help="Port number for CoSApp Lab server",
 )
-def load_module(module, file, all, arguments, port):
+@click.option(
+    "-pre",
+    "--url_prefix",
+    default="",
+    required=False,
+    nargs=1,
+    type=str,
+    help="Prefix of application URL",
+)
+def load_module(module, file, all, arguments, port, url_prefix):
     """Start a CoSApp standalone module. Use -f/--file option to start server from a python script
 
     - MODULE: named of registered CoSApp module.
     """
+    echo(LOGO)
     if all:
         cosapp_script["cosapp_load_module"]("__all__", arguments)
     else:
