@@ -4,7 +4,6 @@ from .cosapp_module import (
     cosapp_load_file,
     cosapp_module_register,
     cosapp_module_list,
-    cosapp_module_update,
     cosapp_module_remove,
     cosapp_load_module,
 )
@@ -16,6 +15,5 @@ cosapp_script = {
     "cosapp_load_module": cosapp_load_module,
     "cosapp_module_register": cosapp_module_register,
     "cosapp_module_list": cosapp_module_list,
-    "cosapp_module_update": cosapp_module_update,
     "cosapp_module_remove": cosapp_module_remove,
 }
