@@ -1,4 +1,4 @@
-import { StateInterface } from '../../chart_viewer_react/redux/types';
+import { StateInterface } from '../../widgets/redux/types';
 
 export const mockState: StateInterface = {
   mainState: {
